summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--gcc/ChangeLog25
-rw-r--r--gcc/alias.c6
-rw-r--r--gcc/basic-block.h2
-rw-r--r--gcc/c-common.c6
-rw-r--r--gcc/c-common.h2
-rw-r--r--gcc/c-decl.c4
-rw-r--r--gcc/c-opts.c2
-rw-r--r--gcc/c-pragma.c2
-rw-r--r--gcc/c-pretty-print.h2
-rw-r--r--gcc/cfg.c2
-rw-r--r--gcc/cfganal.c2
-rw-r--r--gcc/cfgbuild.c2
-rw-r--r--gcc/cfgcleanup.c12
-rw-r--r--gcc/cfglayout.c2
-rw-r--r--gcc/cfgrtl.c2
-rw-r--r--gcc/convert.c2
-rw-r--r--gcc/cpphash.h2
-rw-r--r--gcc/cpplex.c2
-rw-r--r--gcc/cpplib.h6
-rw-r--r--gcc/df.h4
-rw-r--r--gcc/diagnostic.c4
-rw-r--r--gcc/diagnostic.h4
-rw-r--r--gcc/dwarf2.h2
23 files changed, 62 insertions, 37 deletions
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index cfca9bfbb8e..5e5e1ba3b23 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,28 @@
+2003-01-17 Kazu Hirata <kazu@cs.umass.edu>
+
+ * alias.c: Fix comment typos.
+ * basic-block.h: Likewise.
+ * c-common.c: Likewise.
+ * c-common.h: Likewise.
+ * c-decl.c: Likewise.
+ * c-opts.c: Likewise.
+ * c-pragma.c: Likewise.
+ * c-pretty-print.h: Likewise.
+ * cfg.c: Likewise.
+ * cfganal.c: Likewise.
+ * cfgbuild.c: Likewise.
+ * cfgcleanup.c: Likewise.
+ * cfglayout.c: Likewise.
+ * cfgrtl.c: Likewise.
+ * convert.c: Likewise.
+ * cpphash.h: Likewise.
+ * cpplex.c: Likewise.
+ * cpplib.h: Likewise.
+ * df.h: Likewise.
+ * diagnostic.c: Likewise.
+ * diagnostic.h: Likewise.
+ * dwarf2.h: Likewise.
+
2003-01-17 Stan Shebs <shebs@apple.com>
* config/darwin-protos.h: Forward-declare struct cpp_reader.
diff --git a/gcc/alias.c b/gcc/alias.c
index ffd4991a2c6..23f41341844 100644
--- a/gcc/alias.c
+++ b/gcc/alias.c
@@ -64,7 +64,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
To see whether two alias sets can point to the same memory, we must
see if either alias set is a subset of the other. We need not trace
- past immediate descendents, however, since we propagate all
+ past immediate descendants, however, since we propagate all
grandchildren up one level.
Alias set zero is implicitly a superset of all other alias sets.
@@ -77,7 +77,7 @@ typedef struct alias_set_entry
HOST_WIDE_INT alias_set;
/* The children of the alias set. These are not just the immediate
- children, but, in fact, all descendents. So, if we have:
+ children, but, in fact, all descendants. So, if we have:
struct T { struct S s; float f; }
@@ -1953,7 +1953,7 @@ adjust_offset_for_component_ref (x, offset)
return GEN_INT (ioffset);
}
-/* Return nonzero if we can deterimine the exprs corresponding to memrefs
+/* Return nonzero if we can determine the exprs corresponding to memrefs
X and Y and they do not overlap. */
static int
diff --git a/gcc/basic-block.h b/gcc/basic-block.h
index 78b7ac6b3f4..5dd0007b289 100644
--- a/gcc/basic-block.h
+++ b/gcc/basic-block.h
@@ -478,7 +478,7 @@ struct loop
This does not include loop exits due to return instructions.
This is because all bivs and givs are pseudos, and hence must be
- dead after a return, so the presense of a return does not affect
+ dead after a return, so the presence of a return does not affect
any of the optimizations that use this info. It is simpler to
just not include return instructions on this list. */
rtx exit_labels;
diff --git a/gcc/c-common.c b/gcc/c-common.c
index 84166c98da3..2eb2eb7e8c8 100644
--- a/gcc/c-common.c
+++ b/gcc/c-common.c
@@ -872,7 +872,7 @@ const struct attribute_spec c_common_attribute_table[] =
};
/* Give the specifications for the format attributes, used by C and all
- descendents. */
+ descendants. */
const struct attribute_spec c_common_format_attribute_table[] =
{
@@ -2994,7 +2994,7 @@ c_common_get_alias_set (t)
if (! TYPE_P (t))
return -1;
- /* The C standard guarantess that any object may be accessed via an
+ /* The C standard guarantees that any object may be accessed via an
lvalue that has character type. */
if (t == char_type_node
|| t == signed_char_type_node
@@ -6355,7 +6355,7 @@ handle_nonnull_attribute (node, name, args, flags, no_add_attrs)
unsigned HOST_WIDE_INT attr_arg_num;
/* If no arguments are specified, all pointer arguments should be
- non-null. Veryify a full prototype is given so that the arguments
+ non-null. Verify a full prototype is given so that the arguments
will have the correct types when we actually check them later. */
if (! args)
{
diff --git a/gcc/c-common.h b/gcc/c-common.h
index 3e976621711..8164fa80942 100644
--- a/gcc/c-common.h
+++ b/gcc/c-common.h
@@ -1010,7 +1010,7 @@ extern tree strip_array_types PARAMS ((tree));
/* GOTO_STMT accessor. This gives access to the label associated with
a goto statement. */
#define GOTO_DESTINATION(NODE) TREE_OPERAND (GOTO_STMT_CHECK (NODE), 0)
-/* True for goto created artifically by the compiler. */
+/* True for goto created artificially by the compiler. */
#define GOTO_FAKE_P(NODE) (TREE_LANG_FLAG_0 (GOTO_STMT_CHECK (NODE)))
/* COMPOUND_STMT accessor. This gives access to the TREE_LIST of
diff --git a/gcc/c-decl.c b/gcc/c-decl.c
index e3d07aab96d..c6aa2709dcc 100644
--- a/gcc/c-decl.c
+++ b/gcc/c-decl.c
@@ -2922,7 +2922,7 @@ start_decl (declarator, declspecs, initialized, attributes)
Thread-local variables are never common, since there's no entrenched
body of code to break, and it allows more efficient variable references
- in the presense of dynamic linking. */
+ in the presence of dynamic linking. */
if (TREE_CODE (decl) == VAR_DECL
&& !initialized
@@ -5024,7 +5024,7 @@ grokfield (filename, line, declarator, declspecs, width)
again this is an anonymous struct.
Otherwise this is an error.
- Oh what a horrid tangled web we weave. I wonder if MS consiously
+ Oh what a horrid tangled web we weave. I wonder if MS consciously
took this from Plan 9 or if it was an accident of implementation
that took root before someone noticed the bug... */
diff --git a/gcc/c-opts.c b/gcc/c-opts.c
index 5270d625a20..bb074615e2a 100644
--- a/gcc/c-opts.c
+++ b/gcc/c-opts.c
@@ -314,7 +314,7 @@ static const struct cl_option cl_options[] =
#undef COMMAND_LINE_OPTIONS
/* Holds switches parsed by c_common_decode_option (), but whose
- handling is deffered to c_common_post_options (). */
+ handling is deferred to c_common_post_options (). */
static void defer_opt PARAMS ((enum opt_code, const char *));
static struct deferred_opt
{
diff --git a/gcc/c-pragma.c b/gcc/c-pragma.c
index d489cdca0da..78e9d9dd105 100644
--- a/gcc/c-pragma.c
+++ b/gcc/c-pragma.c
@@ -424,7 +424,7 @@ handle_pragma_extern_prefix (dummy)
}
#endif
-/* Hook from the front ends to apply the results of one of the preceeding
+/* Hook from the front ends to apply the results of one of the preceding
pragmas that rename variables. */
tree
diff --git a/gcc/c-pretty-print.h b/gcc/c-pretty-print.h
index 013ab6fa4a6..3bdd6fec4a7 100644
--- a/gcc/c-pretty-print.h
+++ b/gcc/c-pretty-print.h
@@ -42,7 +42,7 @@ struct c_pretty_print_info
int *offset_list;
/* These must be overridden by each of the C and C++ front-end to
- reflect their understanding of syntatic productions when they differ. */
+ reflect their understanding of syntactic productions when they differ. */
c_pretty_print_fn declaration;
c_pretty_print_fn declaration_specifiers;
c_pretty_print_fn type_specifier;
diff --git a/gcc/cfg.c b/gcc/cfg.c
index 1bfba7d111f..ec9fff5f465 100644
--- a/gcc/cfg.c
+++ b/gcc/cfg.c
@@ -572,7 +572,7 @@ dump_flow_info (file)
/* Check the consistency of profile information. We can't do that
in verify_flow_info, as the counts may get invalid for incompletely
- solved graphs, later elliminating of conditionals or roundoff errors.
+ solved graphs, later eliminating of conditionals or roundoff errors.
It is still practical to have them reported for debugging of simple
testcases. */
sum = 0;
diff --git a/gcc/cfganal.c b/gcc/cfganal.c
index 325a64df1f8..adbe8661124 100644
--- a/gcc/cfganal.c
+++ b/gcc/cfganal.c
@@ -234,7 +234,7 @@ set_edge_can_fallthru_flag ()
e->flags |= EDGE_CAN_FALLTHRU;
}
- /* If the BB ends with an invertable condjump all (2) edges are
+ /* If the BB ends with an invertible condjump all (2) edges are
CAN_FALLTHRU edges. */
if (!bb->succ || !bb->succ->succ_next || bb->succ->succ_next->succ_next)
continue;
diff --git a/gcc/cfgbuild.c b/gcc/cfgbuild.c
index 7bc33f248d0..2e1830c924f 100644
--- a/gcc/cfgbuild.c
+++ b/gcc/cfgbuild.c
@@ -148,7 +148,7 @@ count_basic_blocks (f)
for (insn = f; insn; insn = NEXT_INSN (insn))
{
- /* Code labels and barriers causes curent basic block to be
+ /* Code labels and barriers causes current basic block to be
terminated at previous real insn. */
if ((GET_CODE (insn) == CODE_LABEL || GET_CODE (insn) == BARRIER)
&& saw_insn)
diff --git a/gcc/cfglayout.c b/gcc/cfglayout.c
index e50f2ff856d..9c52ac1fd54 100644
--- a/gcc/cfglayout.c
+++ b/gcc/cfglayout.c
@@ -717,7 +717,7 @@ cfg_layout_can_duplicate_bb_p (bb)
return false;
/* Do not attempt to duplicate tablejumps, as we need to unshare
- the dispatch table. This is dificult to do, as the instructions
+ the dispatch table. This is difficult to do, as the instructions
computing jump destination may be hoisted outside the basic block. */
if (GET_CODE (bb->end) == JUMP_INSN && JUMP_LABEL (bb->end)
&& (next = next_nonnote_insn (JUMP_LABEL (bb->end)))
diff --git a/gcc/cfgrtl.c b/gcc/cfgrtl.c
index ef233315a33..07f4a8c0957 100644
--- a/gcc/cfgrtl.c
+++ b/gcc/cfgrtl.c
@@ -33,7 +33,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
- Edge redirection with updating and optimizing of insn chain
block_label, redirect_edge_and_branch,
redirect_edge_and_branch_force, tidy_fallthru_edge, force_nonfallthru
- - Edge splitting and commiting to edges
+ - Edge splitting and committing to edges
split_edge, insert_insn_on_edge, commit_edge_insertions
- Dumping and debugging
print_rtl_with_bb, dump_bb, debug_bb, debug_bb_n
diff --git a/gcc/convert.c b/gcc/convert.c
index 009675ff19f..30aa629a450 100644
--- a/gcc/convert.c
+++ b/gcc/convert.c
@@ -155,7 +155,7 @@ convert_to_real (type, expr)
if (TYPE_PRECISION (TREE_TYPE (arg0)) > TYPE_PRECISION (type))
newtype = TREE_TYPE (arg0);
- /* Be curefull about integer to fp conversions.
+ /* Be careful about integer to fp conversions.
These may overflow still. */
if (FLOAT_TYPE_P (TREE_TYPE (arg0))
&& TYPE_PRECISION (newtype) <= TYPE_PRECISION (itype)
diff --git a/gcc/cpphash.h b/gcc/cpphash.h
index d5a0b5d155a..75f6bc5e2fc 100644
--- a/gcc/cpphash.h
+++ b/gcc/cpphash.h
@@ -362,7 +362,7 @@ struct cpp_reader
_cpp_maybe_push_include_file has yet to restore the line map. */
struct pending_option **next_include_file;
- /* Multiple inlcude optimisation. */
+ /* Multiple include optimisation. */
const cpp_hashnode *mi_cmacro;
const cpp_hashnode *mi_ind_cmacro;
bool mi_valid;
diff --git a/gcc/cpplex.c b/gcc/cpplex.c
index e8d7b7e56d6..4427b3e3e1e 100644
--- a/gcc/cpplex.c
+++ b/gcc/cpplex.c
@@ -607,7 +607,7 @@ unescaped_terminator_p (pfile, dest)
{
const unsigned char *start, *temp;
- /* In #include-style directives, terminators are not escapeable. */
+ /* In #include-style directives, terminators are not escapable. */
if (pfile->state.angled_headers)
return 1;
diff --git a/gcc/cpplib.h b/gcc/cpplib.h
index bccfecf86be..556c78381f3 100644
--- a/gcc/cpplib.h
+++ b/gcc/cpplib.h
@@ -434,7 +434,7 @@ extern const char *progname;
entries for all identifiers: either macros defined by #define
commands (type NT_MACRO), assertions created with #assert
(NT_ASSERTION), or neither of the above (NT_VOID). Builtin macros
- like __LINE__ are flagged NODE_BUILTIN. Poisioned identifiers are
+ like __LINE__ are flagged NODE_BUILTIN. Poisoned identifiers are
flagged NODE_POISONED. NODE_OPERATOR (C++ only) indicates an
identifier that behaves like an operator such as "xor".
NODE_DIAGNOSTIC is for speed in lex_token: it indicates a
@@ -544,7 +544,7 @@ extern int cpp_handle_option PARAMS ((cpp_reader *, int, char **));
too. If there was an error opening the file, it returns NULL.
If you want cpplib to manage its own hashtable, pass in a NULL
- pointer. Otherise you should pass in an initialized hash table
+ pointer. Otherwise you should pass in an initialized hash table
that cpplib will share; this technique is used by the C front
ends. */
extern const char *cpp_read_main_file PARAMS ((cpp_reader *, const char *,
@@ -654,7 +654,7 @@ extern cpp_num cpp_interpret_integer PARAMS ((cpp_reader *, const cpp_token *,
others assumed clear, to fill out a cpp_num structure. */
cpp_num cpp_num_sign_extend PARAMS ((cpp_num, size_t));
-/* Diagnostic levels. To get a dianostic without associating a
+/* Diagnostic levels. To get a diagnostic without associating a
position in the translation unit with it, use cpp_error_with_line
with a line number of zero. */
diff --git a/gcc/df.h b/gcc/df.h
index 59f314384a2..6324a6bf982 100644
--- a/gcc/df.h
+++ b/gcc/df.h
@@ -57,7 +57,7 @@ enum df_ref_flags
and where the mode change of that subreg expression is invalid for
this class. Note, that this flag can also be set on df_refs
representing the REG itself (i.e. one might not see the subreg
- anyore). Also note, that this flag is set also for hardreg refs.
+ anymore). Also note, that this flag is set also for hardreg refs.
I.e. you must check yourself if it's a pseudo. */
DF_REF_MODE_CHANGE = 2
};
@@ -80,7 +80,7 @@ struct insn_info
{
struct df_link *defs; /* Head of insn-def chain. */
struct df_link *uses; /* Head of insn-use chain. */
- /* ???? The following luid field should be considerd private so that
+ /* ???? The following luid field should be considered private so that
we can change it on the fly to accommodate new insns? */
int luid; /* Logical UID. */
#if 0
diff --git a/gcc/diagnostic.c b/gcc/diagnostic.c
index 015d2c4e291..a192229bd59 100644
--- a/gcc/diagnostic.c
+++ b/gcc/diagnostic.c
@@ -644,7 +644,7 @@ build_message_string VPARAMS ((const char *msg, ...))
return str;
}
-/* Same as diagnsotic_build_prefix, but only the source FILE is given. */
+/* Same as diagnostic_build_prefix, but only the source FILE is given. */
char *
file_name_as_prefix (f)
const char *f;
@@ -817,7 +817,7 @@ diagnostic_set_info (diagnostic, msgid, args, file, line, kind)
{
diagnostic->message.format_spec = msgid;
diagnostic->message.args_ptr = args;
- /* If the diagnostic message doesn't specify a loccation,
+ /* If the diagnostic message doesn't specify a location,
use FILE and LINE. */
if (!text_specifies_location (&diagnostic->message, &diagnostic->location))
{
diff --git a/gcc/diagnostic.h b/gcc/diagnostic.h
index aad9a58cbed..2bb0f8af349 100644
--- a/gcc/diagnostic.h
+++ b/gcc/diagnostic.h
@@ -33,7 +33,7 @@ typedef struct
va_list *args_ptr;
} text_info;
-/* Contants used to discreminate diagnostics. */
+/* Contants used to discriminate diagnostics. */
typedef enum
{
#define DEFINE_DIAGNOSTIC_KIND(K, M) K,
@@ -282,7 +282,7 @@ extern diagnostic_context *global_dc;
#define report_diagnostic(D) diagnostic_report_diagnostic (global_dc, D)
-/* Dignostic related functions. */
+/* Diagnostic related functions. */
extern void diagnostic_initialize PARAMS ((diagnostic_context *));
extern void diagnostic_report_current_module PARAMS ((diagnostic_context *));
extern void diagnostic_report_current_function PARAMS ((diagnostic_context *));
diff --git a/gcc/dwarf2.h b/gcc/dwarf2.h
index a7f5f0f8d68..2345d3aad14 100644
--- a/gcc/dwarf2.h
+++ b/gcc/dwarf2.h
@@ -4,7 +4,7 @@
Free Software Foundation, Inc.
Written by Gary Funck (gary@intrepid.com) The Ada Joint Program
- Office (AJPO), Florida State Unviversity and Silicon Graphics Inc.
+ Office (AJPO), Florida State University and Silicon Graphics Inc.
provided support for this effort -- June 21, 1995.
Derived from the DWARF 1 implementation written by Ron Guilmette
diff --git a/gcc/cfgcleanup.c b/gcc/cfgcleanup.c
index ad507a1cd59..19e9fd54468 100644
--- a/gcc/cfgcleanup.c
+++ b/gcc/cfgcleanup.c
@@ -263,7 +263,7 @@ mentions_nonequal_regs (x, data)
return 0;
}
/* Attempt to prove that the basic block B will have no side effects and
- allways continues in the same edge if reached via E. Return the edge
+ always continues in the same edge if reached via E. Return the edge
if exist, NULL otherwise. */
static edge
@@ -323,7 +323,7 @@ thread_jump (mode, e, b)
return NULL;
/* Ensure that the comparison operators are equivalent.
- ??? This is far too pesimistic. We should allow swapped operands,
+ ??? This is far too pessimistic. We should allow swapped operands,
different CCmodes, or for example comparisons for interval, that
dominate even when operands are not equivalent. */
if (!rtx_equal_p (XEXP (cond1, 0), XEXP (cond2, 0))
@@ -1146,7 +1146,7 @@ outgoing_edges_match (mode, bb1, bb2)
/* Do not crossjump across loop boundaries. This is a temporary
workaround for the common scenario in which crossjumping results
in killing the duplicated loop condition, making bb-reorder rotate
- the loop incorectly, leaving an extra unconditional jump inside
+ the loop incorrectly, leaving an extra unconditional jump inside
the loop.
This check should go away once bb-reorder knows how to duplicate
@@ -1776,7 +1776,7 @@ cleanup_cfg (mode)
{
changed = true;
/* We've possibly created trivially dead code. Cleanup it right
- now to introduce more oppurtunities for try_optimize_cfg. */
+ now to introduce more opportunities for try_optimize_cfg. */
if (!(mode & (CLEANUP_NO_INSN_DEL
| CLEANUP_UPDATE_LIFE | CLEANUP_PRE_SIBCALL))
&& !reload_completed)
@@ -1790,8 +1790,8 @@ cleanup_cfg (mode)
delete_unreachable_blocks (), changed = true;
if (mode & CLEANUP_UPDATE_LIFE)
{
- /* Cleaning up CFG introduces more oppurtunities for dead code
- removal that in turn may introduce more oppurtunities for
+ /* Cleaning up CFG introduces more opportunities for dead code
+ removal that in turn may introduce more opportunities for
cleaning up the CFG. */
if (!update_life_info_in_dirty_blocks (UPDATE_LIFE_GLOBAL_RM_NOTES,
PROP_DEATH_NOTES